@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 EXEC_USER=`/usr/bin/whoami`
 if [ ${EXEC_USER} != "hinemos" -a ${EXEC_USER} != "root" ]; then
         echo "";
-        echo "ERROR  Hienmos Maneger boot at incorrect user ";
+        echo "ERROR  Hinemos Maneger boot at incorrect user ";
         echo "";
         exit 1;
 fi
@@ -46,7 +46,7 @@ if [ -f ${HINEMOS_JBOSS_PID} ] ; then
         if [ "$TMP" ] ; then
                 echo ""
                 echo "======================================================"
-                echo "ERROR another jboss may be runnning."
+                echo "ERROR another jboss may be running."
                 echo "pid file (${HINEMOS_JBOSS_PID}) is exist."
                 echo "======================================================"
                 exit 24
@@ -63,7 +63,7 @@ do
 	case $OPTION in
 		-c)
 			echo "After the JMS message is annulled, JBoss is started. "
-			rm -rf ${HINEMOS_HOME}/jboss-4.0.3SP1/server/default/data/hypersonic/*
+			rm -rf ${HINEMOS_HOME}/jboss-4.2.2.GA/server/default/data/hypersonic/*
 			;;
 		*)
 			;;
@@ -71,7 +71,7 @@ do
 done
 
 
-nohup ${HINEMOS_HOME}/jboss-4.0.3SP1/bin/run_hinemos.sh > ${HINEMOS_HOME}/var/log/jboss_stdout.log &
+nohup ${HINEMOS_HOME}/jboss-4.2.2.GA/bin/run_hinemos.sh -b ${IP_ADDRESS} > ${HINEMOS_HOME}/var/log/jboss_stdout.log &
 
 TODAY=`date +%Y-%m-%d`
 TIME_COUNT=0
@@ -84,15 +84,14 @@ do
         if [ -f ${HINEMOS_HOME}/var/log/jboss.log ]; then
                 LOG_DATE=`tail -1 /opt/hinemos/var/log/jboss.log | gawk -F\  '{ print $1 }'`
                 if [ "${TODAY}" = "${LOG_DATE}" ];  then
-#                RUN_COUNT=`grep running ${HINEMOS_HOME}/var/log/jboss.log | wc -l`
-                RUN_COUNT=`grep 'JBoss (MX MicroKernel).*Started' ${HINEMOS_HOME}/var/log/jboss.log | wc -l`
-                EXCEPTION_COUNT=`grep Exception ${HINEMOS_HOME}/var/log/jboss.log | wc -l`
+                RUN_COUNT=`grep -a 'JBoss (MX MicroKernel).*Started' ${HINEMOS_HOME}/var/log/jboss.log | wc -l`
+                EXCEPTION_COUNT=`grep -a Exception ${HINEMOS_HOME}/var/log/jboss.log | wc -l`
 
                 while [ 1 ] ;
                 do
-                        if [ `grep running ${HINEMOS_HOME}/var/log/jboss.log | wc -l` -gt ${RUN_COUNT} ] ; then
+                        if [ `grep -a 'JBoss (MX MicroKernel).*Started' ${HINEMOS_HOME}/var/log/jboss.log | wc -l` -gt ${RUN_COUNT} ] ; then
                                 break;
-                        elif [ `grep Exception ${HINEMOS_HOME}/var/log/jboss.log | wc -l` -gt ${EXCEPTION_COUNT} ] ; then
+                        elif [ `grep -a Exception ${HINEMOS_HOME}/var/log/jboss.log | wc -l` -gt ${EXCEPTION_COUNT} ] ; then
                                 echo ""
                                 echo "Exception occurred. It may not start normally."
                                         echo "Please check ${HINEMOS_HOME}/var/log/jboss.log ."
@@ -103,7 +102,7 @@ do
 
                         TIME_COUNT=$((${TIME_COUNT} + 2))
                         if [ "${TIME_COUNT}" -ge 120 ]; then
-                                STATE_STRING=`${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 get "jboss.system:type=Server" Started`
+                                STATE_STRING=`${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 get "jboss.system:type=Server" Started`
                                 if [ "${STATE_STRING}" = "Started=true" ]; then
                                         break;
                                 fi
@@ -124,6 +123,6 @@ done
 
 #copy jboss boot.log to /opt/hinemos/var/log/boot.log.XXXX-XX-XX
 SDATE=`date +%Y-%m-%d`
-cat ${HINEMOS_HOME}/jboss-4.0.3SP1/server/default/log/boot.log >>${HINEMOS_HOME}/var/log/boot.log.${SDATE}
+cat ${HINEMOS_HOME}/jboss-4.2.2.GA/server/default/log/boot.log >>${HINEMOS_HOME}/var/log/boot.log.${SDATE}
 
 echo "jboss started"
