@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@ fi
 
 # JBoss shutdown
 echo "waiting for jboss to stop..."
-${HINEMOS_HOME}/jboss-4.0.3SP1/bin/shutdown_hinemos.sh -S
+${HINEMOS_HOME}/jboss-4.2.2.GA/bin/shutdown_hinemos.sh -S -s ${IP_ADDRESS}
 REVAL=$?
                                                                                                      
 if [ $REVAL -ne 0 ] ; then
