@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 EXEC_USER=`/usr/bin/whoami`
 if [ ${EXEC_USER} != "hinemos" ]; then
         echo "";
-        echo "ERROR  Hienmos Maneger boot at incorrect user ";
+        echo "ERROR  Hinemos Maneger boot at incorrect user ";
         echo "";
         exit 1;
 fi
@@ -39,7 +39,7 @@ if [ -f ${HINEMOS_LDAP_PID} ] ; then
 fi
 
 echo "waiting for slapd to start..."
-${HINEMOS_HOME}/openldap-2.3.20/libexec/slapd -h "ldap://0.0.0.0:24000/"
+${HINEMOS_HOME}/openldap-2.3.39/libexec/slapd -h "ldap://0.0.0.0:24000/"
 REVAL=$?
 if [ $REVAL -ne 0 ]; then
         echo "ERROR  It may not start normally."
