@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 EXEC_USER=`/usr/bin/whoami`
 if [ ${EXEC_USER} != "hinemos" ]; then
         echo "";
-        echo "ERROR  Hienmos Maneger shutdown at incorrect user ";
+        echo "ERROR  Hinemos Maneger shutdown at incorrect user ";
         echo "";
         exit 1;
 fi
