@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -17,12 +17,12 @@ HINEMOS_HOME=`pwd`
 . ${HINEMOS_HOME}/hinemos.cfg
 
 #DBクラスタの初期化
-${PG}/bin/initdb --no-local --encoding=UNICODE -D $PGDATA > /dev/null 2>&1
-#${PG}/bin/initdb --no-local -D $PGDATA > /dev/null 2>&1
-#${PG}/bin/initdb --no-local -D $PGDATA 
+${PG}/bin/initdb --no-locale --encoding=UNICODE -D $PGDATA > /dev/null 2>&1
 
-#ファイルのコピー
-cp -p ${HINEMOS_HOME}/sbin/db_init/postgresql.conf $PGDATA
+#ファイルのシンボリックリンク作成
+#cp -p ${HINEMOS_HOME}/sbin/db_init/postgresql.conf $PGDATA
+rm -f $PGDATA/postgresql.conf
+ln -s ../../etc/postgresql.conf var/data/
 
 #PostgreSQLの起動
 ${HINEMOS_HOME}/bin/pg_start.sh
@@ -44,5 +44,7 @@ ${PG}/bin/psql -p 24001 -c "ALTER USER hinemos PASSWORD 'hinemos'"
 #PostgreSQLの停止
 ${HINEMOS_HOME}/bin/pg_stop.sh
 
-#ファイルのコピー
-cp -p ${HINEMOS_HOME}/sbin/db_init/pg_hba.conf $PGDATA
+#ファイルのシンボリックリンク作成
+#cp -p ${HINEMOS_HOME}/sbin/db_init/pg_hba.conf $PGDATA
+rm -f $PGDATA/pg_hba.conf
+ln -s ../../etc/pg_hba.conf var/data/
