@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -98,11 +98,18 @@ make_user() {
 	
 	#${HINEMOS_USER}が存在する場合
 	if [ "$TMP" -eq "1" ] ; then
-		echo "ユーザ ${HINEMOS_USER} は既に存在します。"	
+		echo "ユーザ ${HINEMOS_USER} は既に存在します。"
+		
+		mkdir -p ${HINEMOS_HOME}
+		chown -R ${HINEMOS_USER}:${HINEMOS_USER} ${HINEMOS_HOME}
+		cp ${EXEC_PATH}/bash_profile.conf ${HINEMOS_HOME}/.bash_profile
+		echo "インストールディレクトリ ${HINEMOS_HOME} を作成しました。"
 	else
-		/usr/sbin/useradd ${HINEMOS_USER}
+		/usr/sbin/useradd ${HINEMOS_USER} -d ${HINEMOS_HOME}
 		/usr/bin/passwd ${HINEMOS_USER}
+		cp ${EXEC_PATH}/bash_profile.conf ${HINEMOS_HOME}/.bash_profile
 		echo "ユーザ ${HINEMOS_USER} を作成しました。"
+		echo "インストールディレクトリ ${HINEMOS_HOME} を作成しました。"
 	fi
 	sleep 2
 }
@@ -110,8 +117,7 @@ make_user() {
 ##
 ## インストールディレクトリの確認
 ##
-make_installdir() {
-	echo "インストールディレクトリ ${HINEMOS_HOME} を作成します。"
+make_installdir_check() {
 	if [ -d ${HINEMOS_HOME} ] ; then
 		echo "警告：インストールディレクトリ ${HINEMOS_HOME} は既に存在します。"
 		echo "ディレクトリ名を変更するか、削除してください。"
@@ -119,10 +125,6 @@ make_installdir() {
 		echo "インストールを中止します。"
 		sleep 2
 		exit 1
-	else
-		mkdir -p ${HINEMOS_HOME}
-		chown -R ${HINEMOS_USER}:${HINEMOS_USER} ${HINEMOS_HOME}
-		echo "インストールディレクトリ ${HINEMOS_HOME} を作成しました。"
 	fi
 }
 
@@ -191,6 +193,7 @@ hosts_check() {
 	#/etc/hostsの設定
 	HOSTS_FILE=/etc/hosts
 	HOST=`hostname`
+	IPADDRESS=${1}
 	
 	while [ 1 ] ;
 	do
@@ -201,27 +204,6 @@ hosts_check() {
 		echo ""
 		case ${ANS} in
 			y|Y)
-				#IPアドレスの取得
-				while [ 1 ] ;
-				do
-					echo "現在マネージャをインストールしているマシンのIPアドレスを入力してください。"
-					read IPADDRESS
-					echo "${IPADDRESS} でよろしいですか? (Y/N default:Y)"
-					read IP_ANS
-					IP_ANS=${IP_ANS:-Y}
-					echo ""
-					case ${IP_ANS} in
-						y|Y)
-							break
-							;;
-						n|N)
-							;;
-						*)
-							echo "YかNを入力して下さい。"
-							;;
-					esac
-				done
-				
 				#hostsファイルのバックアップを取る
 				#バックアップ用時刻を取得
 				DATE=`date +%m%d%H%M`
@@ -296,26 +278,49 @@ do
 			echo "インストールユーザとインストールディレクトリを作成します。"
 			echo ""
 			
-			# インストールユーザの作成
+			# インストールディレクトリの確認
+			make_installdir_check
+			echo ""
+			
+			# インストールユーザとインストールディレクトリの作成
 			make_user
 			echo ""
 			
-			# インストールディレクトリの作成
-			make_installdir			
-			echo ""
+			# IPアドレスの取得
+			echo "マネージャのIPアドレスを設定します。"
+			while [ 1 ] ;
+			do
+				echo "現在マネージャをインストールしているマシンのIPアドレスを入力してください。"
+				read IP_ADDRESS
+				echo "${IP_ADDRESS} でよろしいですか? (Y/N default:Y)"
+				read IP_ANS
+				IP_ANS=${IP_ANS:-Y}
+				echo ""
+				case ${IP_ANS} in
+					y|Y)
+						break
+						;;
+					n|N)
+						;;
+					*)
+						echo "YかNを入力して下さい。"
+						;;
+				esac
+			done			
 			
 			# /opt/hinemos以下にコピー
 			echo "必要なファイルをインストールディレクトリにコピーします。"
 			cp -pr ${EXEC_PATH}/hinemos /opt
 			
-			#インストールディレクトリに応じて各設定ファイルを変更
-			REPLACE_PATH=`echo ${HINEMOS_HOME} | sed 's/\//\\\\\//g'`
-			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
-			
-			
 			# 一括制御の設定
 			crun_setting
 			
+			#インストールディレクトリに応じて各設定ファイルを変更
+			REPLACE_PATH=`echo ${HINEMOS_HOME} | sed 's/\//\\\\\//g'`
+#			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" -e "s/%%ip_address%%/${IP_ADDRESS}/" -e "s/%%hinemos_ftp_host%%/${FTP_SERVER}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
+			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" -e "s/%%ip_address%%/${IP_ADDRESS}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
+			sed -e "s/%%ip_address%%/${IP_ADDRESS}/" ${EXEC_PATH}/hinemos/lib/syslogforward/LogForward.properties > ${HINEMOS_HOME}/lib/syslogforward/LogForward.properties
+			
 			echo "必要なファイルのコピーが終了しました。"
 			echo ""
 			
@@ -338,12 +343,14 @@ do
 			# fpingのオーナーはrootユーザである必要があるため変更する
 			chown root:root ${HINEMOS_HOME}/sbin/fping
 			chmod 4755 ${HINEMOS_HOME}/sbin/fping
+			chown root:root ${HINEMOS_HOME}/sbin/fping6
+			chmod 4755 $HINEMOS_HOME/sbin/fping6
 			
 			# syslog-ngの設定
 			syslogng_install
 			
 			# /etc/hostsの確認
-			hosts_check
+			hosts_check ${IP_ADDRESS}
 			
 			echo ""
 			sleep 1
